from typing import Any

# Enable when pyasn1 gets stubs:
# from pyasn1.type.univ import Enumerated, Sequence
Enumerated = Any
Sequence = Any

class PersistentSearchControl(Sequence):
    componentType: Any

class ChangeType(Enumerated):
    namedValues: Any

class EntryChangeNotificationControl(Sequence):
    componentType: Any

def persistent_search_control(change_types, changes_only: bool = ..., return_ecs: bool = ..., criticality: bool = ...): ...



from typing import Any

class ConnectionUsage:
    open_sockets: int
    closed_sockets: int
    wrapped_sockets: int
    bytes_transmitted: int
    bytes_received: int
    messages_transmitted: int
    messages_received: int
    operations: int
    abandon_operations: int
    add_operations: int
    bind_operations: int
    compare_operations: int
    delete_operations: int
    extended_operations: int
    modify_operations: int
    modify_dn_operations: int
    search_operations: int
    unbind_operations: int
    referrals_received: int
    referrals_followed: int
    referrals_connections: int
    restartable_failures: int
    restartable_successes: int
    servers_from_pool: int
    def reset(self) -> None: ...
    initial_connection_start_time: Any
    open_socket_start_time: Any
    connection_stop_time: Any
    last_transmitted_time: Any
    last_received_time: Any
    def __init__(self) -> None: ...
    def __iadd__(self, other): ...
    def update_transmitted_message(self, message, length) -> None: ...
    def update_received_message(self, length) -> None: ...
    def start(self, reset: bool = ...) -> None: ...
    def stop(self) -> None: ...
    @property
    def elapsed_time(self): ...



from typing import Any

def bind_operation(
    version,
    authentication,
    name: str = ...,
    password: Any | None = ...,
    sasl_mechanism: Any | None = ...,
    sasl_credentials: Any | None = ...,
    auto_encode: bool = ...,
): ...
def bind_request_to_dict(request): ...
def bind_response_operation(
    result_code,
    matched_dn: str = ...,
    diagnostic_message: str = ...,
    referral: Any | None = ...,
    server_sasl_credentials: Any | None = ...,
): ...
def bind_response_to_dict(response): ...
def sicily_bind_response_to_dict(response): ...
def bind_response_to_dict_fast(response): ...
def sicily_bind_response_to_dict_fast(response): ...



from typing import Any

class ExtendedOperation:
    connection: Any
    decoded_response: Any
    result: Any
    asn1_spec: Any
    request_name: Any
    response_name: Any
    request_value: Any
    response_value: Any
    response_attribute: Any
    controls: Any
    def __init__(self, connection, controls: Any | None = ...) -> None: ...
    def send(self): ...
    def populate_result(self) -> None: ...
    def decode_response(self, response: Any | None = ...) -> None: ...
    def set_response(self) -> None: ...
    def config(self) -> None: ...



posix_gssapi_unavailable: bool
windows_gssapi_unavailable: bool
NO_SECURITY_LAYER: int
INTEGRITY_PROTECTION: int
CONFIDENTIALITY_PROTECTION: int

def get_channel_bindings(ssl_socket): ...
def sasl_gssapi(connection, controls): ...



from typing import Any

from ...extend.operation import ExtendedOperation

class ModifyPassword(ExtendedOperation):
    request_name: str
    request_value: Any
    asn1_spec: Any
    response_attribute: str
    def config(self) -> None: ...
    def __init__(
        self,
        connection,
        user: Any | None = ...,
        old_password: Any | None = ...,
        new_password: Any | None = ...,
        hash_algorithm: Any | None = ...,
        salt: Any | None = ...,
        controls: Any | None = ...,
    ) -> None: ...
    def populate_result(self) -> None: ...



from typing import Any

def add_operation(
    dn, attributes, auto_encode, schema: Any | None = ..., validator: Any | None = ..., check_names: bool = ...
): ...
def add_request_to_dict(request): ...
def add_response_to_dict(response): ...



from logging import NullHandler as NullHandler
from typing import Any

OFF: int
ERROR: int
BASIC: int
PROTOCOL: int
NETWORK: int
EXTENDED: int
DETAIL_LEVELS: Any

def get_detail_level_name(level_name): ...
def log(detail, message, *args) -> None: ...
def log_enabled(detail): ...
def set_library_log_hide_sensitive_data(hide: bool = ...) -> None: ...
def get_library_log_hide_sensitive_data(): ...
def set_library_log_activation_level(logging_level) -> None: ...
def get_library_log_activation_lavel(): ...
def set_library_log_max_line_length(length) -> None: ...
def get_library_log_max_line_length(): ...
def set_library_log_detail_level(detail) -> None: ...
def get_library_log_detail_level(): ...
def format_ldap_message(message, prefix): ...

logger: Any



from datetime import tzinfo
from typing import Any

class OffsetTzInfo(tzinfo):
    offset: Any
    name: Any
    def __init__(self, offset, name) -> None: ...
    def utcoffset(self, dt): ...
    def tzname(self, dt): ...
    def dst(self, dt): ...
    def __getinitargs__(self): ...



from setuptools import setup

name = "types-ldap3"
description = "Typing stubs for ldap3"
long_description = '''
## Typing stubs for ldap3

This is a PEP 561 type stub package for the `ldap3` package.
It can be used by type-checking tools like mypy, PyCharm, pytype etc. to check code
that uses `ldap3`. The source for this package can be found at
https://github.com/python/typeshed/tree/master/stubs/ldap3. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/master/README.md for more details.
This package was generated from typeshed commit `74ecc2904b42db498afe309c39b17c10345d1453`.
'''.lstrip()

setup(name=name,
      version="2.9.0",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      install_requires=[],
      packages=['ldap3-stubs'],
      package_data={'ldap3-stubs': ['__init__.pyi', 'abstract/__init__.pyi', 'abstract/attrDef.pyi', 'abstract/attribute.pyi', 'abstract/cursor.pyi', 'abstract/entry.pyi', 'abstract/objectDef.pyi', 'core/__init__.pyi', 'core/connection.pyi', 'core/exceptions.pyi', 'core/pooling.pyi', 'core/rdns.pyi', 'core/results.pyi', 'core/server.pyi', 'core/timezone.pyi', 'core/tls.pyi', 'core/usage.pyi', 'extend/__init__.pyi', 'extend/microsoft/__init__.pyi', 'extend/microsoft/addMembersToGroups.pyi', 'extend/microsoft/dirSync.pyi', 'extend/microsoft/modifyPassword.pyi', 'extend/microsoft/persistentSearch.pyi', 'extend/microsoft/removeMembersFromGroups.pyi', 'extend/microsoft/unlockAccount.pyi', 'extend/novell/__init__.pyi', 'extend/novell/addMembersToGroups.pyi', 'extend/novell/checkGroupsMemberships.pyi', 'extend/novell/endTransaction.pyi', 'extend/novell/getBindDn.pyi', 'extend/novell/listReplicas.pyi', 'extend/novell/nmasGetUniversalPassword.pyi', 'extend/novell/nmasSetUniversalPassword.pyi', 'extend/novell/partition_entry_count.pyi', 'extend/novell/removeMembersFromGroups.pyi', 'extend/novell/replicaInfo.pyi', 'extend/novell/startTransaction.pyi', 'extend/operation.pyi', 'extend/standard/PagedSearch.pyi', 'extend/standard/PersistentSearch.pyi', 'extend/standard/__init__.pyi', 'extend/standard/modifyPassword.pyi', 'extend/standard/whoAmI.pyi', 'operation/__init__.pyi', 'operation/abandon.pyi', 'operation/add.pyi', 'operation/bind.pyi', 'operation/compare.pyi', 'operation/delete.pyi', 'operation/extended.pyi', 'operation/modify.pyi', 'operation/modifyDn.pyi', 'operation/search.pyi', 'operation/unbind.pyi', 'protocol/__init__.pyi', 'protocol/controls.pyi', 'protocol/convert.pyi', 'protocol/formatters/__init__.pyi', 'protocol/formatters/formatters.pyi', 'protocol/formatters/standard.pyi', 'protocol/formatters/validators.pyi', 'protocol/microsoft.pyi', 'protocol/novell.pyi', 'protocol/oid.pyi', 'protocol/persistentSearch.pyi', 'protocol/rfc2696.pyi', 'protocol/rfc2849.pyi', 'protocol/rfc3062.pyi', 'protocol/rfc4511.pyi', 'protocol/rfc4512.pyi', 'protocol/rfc4527.pyi', 'protocol/sasl/__init__.pyi', 'protocol/sasl/digestMd5.pyi', 'protocol/sasl/external.pyi', 'protocol/sasl/kerberos.pyi', 'protocol/sasl/plain.pyi', 'protocol/sasl/sasl.pyi', 'protocol/schemas/__init__.pyi', 'protocol/schemas/ad2012R2.pyi', 'protocol/schemas/ds389.pyi', 'protocol/schemas/edir888.pyi', 'protocol/schemas/edir914.pyi', 'protocol/schemas/slapd24.pyi', 'strategy/__init__.pyi', 'strategy/asyncStream.pyi', 'strategy/asynchronous.pyi', 'strategy/base.pyi', 'strategy/ldifProducer.pyi', 'strategy/mockAsync.pyi', 'strategy/mockBase.pyi', 'strategy/mockSync.pyi', 'strategy/restartable.pyi', 'strategy/reusable.pyi', 'strategy/safeRestartable.pyi', 'strategy/safeSync.pyi', 'strategy/sync.pyi', 'utils/__init__.pyi', 'utils/asn1.pyi', 'utils/ciDict.pyi', 'utils/config.pyi', 'utils/conv.pyi', 'utils/dn.pyi', 'utils/hashed.pyi', 'utils/log.pyi', 'utils/ntlm.pyi', 'utils/port_validators.pyi', 'utils/repr.pyi', 'utils/tls_backport.pyi', 'utils/uri.pyi', 'version.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Typing :: Typed",
      ]
)



STATE_ANY: int
STATE_ESCAPE: int
STATE_ESCAPE_HEX: int

def to_dn(
    iterator, decompose: bool = ..., remove_space: bool = ..., space_around_equal: bool = ..., separate_rdn: bool = ...
): ...
def parse_dn(dn, escape: bool = ..., strip: bool = ...): ...
def safe_dn(dn, decompose: bool = ..., reverse: bool = ...): ...
def safe_rdn(dn, decompose: bool = ...): ...
def escape_rdn(rdn: str) -> str: ...



import socket
from typing import Any, Type, TypeVar

_T = TypeVar("_T")

class LDAPException(Exception): ...

class LDAPOperationResult(LDAPException):
    def __new__(
        cls: Type[_T],
        result: Any | None = ...,
        description: Any | None = ...,
        dn: Any | None = ...,
        message: Any | None = ...,
        response_type: Any | None = ...,
        response: Any | None = ...,
    ) -> _T: ...
    result: Any
    description: Any
    dn: Any
    message: Any
    type: Any
    response: Any
    def __init__(
        self,
        result: Any | None = ...,
        description: Any | None = ...,
        dn: Any | None = ...,
        message: Any | None = ...,
        response_type: Any | None = ...,
        response: Any | None = ...,
    ) -> None: ...

class LDAPOperationsErrorResult(LDAPOperationResult): ...
class LDAPProtocolErrorResult(LDAPOperationResult): ...
class LDAPTimeLimitExceededResult(LDAPOperationResult): ...
class LDAPSizeLimitExceededResult(LDAPOperationResult): ...
class LDAPAuthMethodNotSupportedResult(LDAPOperationResult): ...
class LDAPStrongerAuthRequiredResult(LDAPOperationResult): ...
class LDAPReferralResult(LDAPOperationResult): ...
class LDAPAdminLimitExceededResult(LDAPOperationResult): ...
class LDAPUnavailableCriticalExtensionResult(LDAPOperationResult): ...
class LDAPConfidentialityRequiredResult(LDAPOperationResult): ...
class LDAPSASLBindInProgressResult(LDAPOperationResult): ...
class LDAPNoSuchAttributeResult(LDAPOperationResult): ...
class LDAPUndefinedAttributeTypeResult(LDAPOperationResult): ...
class LDAPInappropriateMatchingResult(LDAPOperationResult): ...
class LDAPConstraintViolationResult(LDAPOperationResult): ...
class LDAPAttributeOrValueExistsResult(LDAPOperationResult): ...
class LDAPInvalidAttributeSyntaxResult(LDAPOperationResult): ...
class LDAPNoSuchObjectResult(LDAPOperationResult): ...
class LDAPAliasProblemResult(LDAPOperationResult): ...
class LDAPInvalidDNSyntaxResult(LDAPOperationResult): ...
class LDAPAliasDereferencingProblemResult(LDAPOperationResult): ...
class LDAPInappropriateAuthenticationResult(LDAPOperationResult): ...
class LDAPInvalidCredentialsResult(LDAPOperationResult): ...
class LDAPInsufficientAccessRightsResult(LDAPOperationResult): ...
class LDAPBusyResult(LDAPOperationResult): ...
class LDAPUnavailableResult(LDAPOperationResult): ...
class LDAPUnwillingToPerformResult(LDAPOperationResult): ...
class LDAPLoopDetectedResult(LDAPOperationResult): ...
class LDAPNamingViolationResult(LDAPOperationResult): ...
class LDAPObjectClassViolationResult(LDAPOperationResult): ...
class LDAPNotAllowedOnNotLeafResult(LDAPOperationResult): ...
class LDAPNotAllowedOnRDNResult(LDAPOperationResult): ...
class LDAPEntryAlreadyExistsResult(LDAPOperationResult): ...
class LDAPObjectClassModsProhibitedResult(LDAPOperationResult): ...
class LDAPAffectMultipleDSASResult(LDAPOperationResult): ...
class LDAPOtherResult(LDAPOperationResult): ...
class LDAPLCUPResourcesExhaustedResult(LDAPOperationResult): ...
class LDAPLCUPSecurityViolationResult(LDAPOperationResult): ...
class LDAPLCUPInvalidDataResult(LDAPOperationResult): ...
class LDAPLCUPUnsupportedSchemeResult(LDAPOperationResult): ...
class LDAPLCUPReloadRequiredResult(LDAPOperationResult): ...
class LDAPCanceledResult(LDAPOperationResult): ...
class LDAPNoSuchOperationResult(LDAPOperationResult): ...
class LDAPTooLateResult(LDAPOperationResult): ...
class LDAPCannotCancelResult(LDAPOperationResult): ...
class LDAPAssertionFailedResult(LDAPOperationResult): ...
class LDAPAuthorizationDeniedResult(LDAPOperationResult): ...
class LDAPESyncRefreshRequiredResult(LDAPOperationResult): ...

exception_table: Any

class LDAPExceptionError(LDAPException): ...
class LDAPConfigurationError(LDAPExceptionError): ...
class LDAPUnknownStrategyError(LDAPConfigurationError): ...
class LDAPUnknownAuthenticationMethodError(LDAPConfigurationError): ...
class LDAPSSLConfigurationError(LDAPConfigurationError): ...
class LDAPDefinitionError(LDAPConfigurationError): ...
class LDAPPackageUnavailableError(LDAPConfigurationError, ImportError): ...
class LDAPConfigurationParameterError(LDAPConfigurationError): ...
class LDAPKeyError(LDAPExceptionError, KeyError, AttributeError): ...
class LDAPObjectError(LDAPExceptionError, ValueError): ...
class LDAPAttributeError(LDAPExceptionError, ValueError, TypeError): ...
class LDAPCursorError(LDAPExceptionError): ...
class LDAPCursorAttributeError(LDAPCursorError, AttributeError): ...
class LDAPObjectDereferenceError(LDAPExceptionError): ...
class LDAPSSLNotSupportedError(LDAPExceptionError, ImportError): ...
class LDAPInvalidTlsSpecificationError(LDAPExceptionError): ...
class LDAPInvalidHashAlgorithmError(LDAPExceptionError, ValueError): ...
class LDAPSignatureVerificationFailedError(LDAPExceptionError): ...
class LDAPBindError(LDAPExceptionError): ...
class LDAPInvalidServerError(LDAPExceptionError): ...
class LDAPSASLMechanismNotSupportedError(LDAPExceptionError): ...
class LDAPConnectionIsReadOnlyError(LDAPExceptionError): ...
class LDAPChangeError(LDAPExceptionError, ValueError): ...
class LDAPServerPoolError(LDAPExceptionError): ...
class LDAPServerPoolExhaustedError(LDAPExceptionError): ...
class LDAPInvalidPortError(LDAPExceptionError): ...
class LDAPStartTLSError(LDAPExceptionError): ...
class LDAPCertificateError(LDAPExceptionError): ...
class LDAPUserNameNotAllowedError(LDAPExceptionError): ...
class LDAPUserNameIsMandatoryError(LDAPExceptionError): ...
class LDAPPasswordIsMandatoryError(LDAPExceptionError): ...
class LDAPInvalidFilterError(LDAPExceptionError): ...
class LDAPInvalidScopeError(LDAPExceptionError, ValueError): ...
class LDAPInvalidDereferenceAliasesError(LDAPExceptionError, ValueError): ...
class LDAPInvalidValueError(LDAPExceptionError, ValueError): ...
class LDAPControlError(LDAPExceptionError, ValueError): ...
class LDAPExtensionError(LDAPExceptionError, ValueError): ...
class LDAPLDIFError(LDAPExceptionError): ...
class LDAPSchemaError(LDAPExceptionError): ...
class LDAPSASLPrepError(LDAPExceptionError): ...
class LDAPSASLBindInProgressError(LDAPExceptionError): ...
class LDAPMetricsError(LDAPExceptionError): ...
class LDAPObjectClassError(LDAPExceptionError): ...
class LDAPInvalidDnError(LDAPExceptionError): ...
class LDAPResponseTimeoutError(LDAPExceptionError): ...
class LDAPTransactionError(LDAPExceptionError): ...
class LDAPInfoError(LDAPExceptionError): ...
class LDAPCommunicationError(LDAPExceptionError): ...
class LDAPSocketOpenError(LDAPCommunicationError): ...
class LDAPSocketCloseError(LDAPCommunicationError): ...
class LDAPSocketReceiveError(LDAPCommunicationError, socket.error): ...
class LDAPSocketSendError(LDAPCommunicationError, socket.error): ...
class LDAPSessionTerminatedByServerError(LDAPCommunicationError): ...
class LDAPUnknownResponseError(LDAPCommunicationError): ...
class LDAPUnknownRequestError(LDAPCommunicationError): ...
class LDAPReferralError(LDAPCommunicationError): ...
class LDAPConnectionPoolNameIsMandatoryError(LDAPExceptionError): ...
class LDAPConnectionPoolNotStartedError(LDAPExceptionError): ...
class LDAPMaximumRetriesError(LDAPExceptionError): ...

def communication_exception_factory(exc_to_raise, exc): ...
def start_tls_exception_factory(exc): ...



from typing import Any

ROOT: int
AND: int
OR: int
NOT: int
MATCH_APPROX: int
MATCH_GREATER_OR_EQUAL: int
MATCH_LESS_OR_EQUAL: int
MATCH_EXTENSIBLE: int
MATCH_PRESENT: int
MATCH_SUBSTRING: int
MATCH_EQUAL: int
SEARCH_OPEN: int
SEARCH_OPEN_OR_CLOSE: int
SEARCH_MATCH_OR_CLOSE: int
SEARCH_MATCH_OR_CONTROL: int

class FilterNode:
    tag: Any
    parent: Any
    assertion: Any
    elements: Any
    def __init__(self, tag: Any | None = ..., assertion: Any | None = ...) -> None: ...
    def append(self, filter_node): ...

def evaluate_match(match, schema, auto_escape, auto_encode, validator, check_names): ...
def parse_filter(search_filter, schema, auto_escape, auto_encode, validator, check_names): ...
def compile_filter(filter_node): ...
def build_attribute_selection(attribute_list, schema): ...
def search_operation(
    search_base,
    search_filter,
    search_scope,
    dereference_aliases,
    attributes,
    size_limit,
    time_limit,
    types_only,
    auto_escape,
    auto_encode,
    schema: Any | None = ...,
    validator: Any | None = ...,
    check_names: bool = ...,
): ...
def decode_vals(vals): ...
def decode_vals_fast(vals): ...
def attributes_to_dict(attribute_list): ...
def attributes_to_dict_fast(attribute_list): ...
def decode_raw_vals(vals): ...
def decode_raw_vals_fast(vals): ...
def raw_attributes_to_dict(attribute_list): ...
def raw_attributes_to_dict_fast(attribute_list): ...
def checked_attributes_to_dict(attribute_list, schema: Any | None = ..., custom_formatter: Any | None = ...): ...
def checked_attributes_to_dict_fast(attribute_list, schema: Any | None = ..., custom_formatter: Any | None = ...): ...
def matching_rule_assertion_to_string(matching_rule_assertion): ...
def filter_to_string(filter_object): ...
def search_request_to_dict(request): ...
def search_result_entry_response_to_dict(response, schema, custom_formatter, check_names): ...
def search_result_done_response_to_dict(response): ...
def search_result_reference_response_to_dict(response): ...
def search_result_entry_response_to_dict_fast(response, schema, custom_formatter, check_names): ...
def search_result_reference_response_to_dict_fast(response): ...



from typing import Any

# Enable when pyasn1 gets stubs:
# from pyasn1.type.univ import Integer, OctetString, Sequence, SequenceOf
Integer = Any
OctetString = Any
Sequence = Any
SequenceOf = Any

NMAS_LDAP_EXT_VERSION: int

class Identity(OctetString):
    encoding: str

class LDAPDN(OctetString):
    tagSet: Any
    encoding: str

class Password(OctetString):
    tagSet: Any
    encoding: str

class LDAPOID(OctetString):
    tagSet: Any
    encoding: str

class GroupCookie(Integer):
    tagSet: Any

class NmasVer(Integer):
    tagSet: Any

class Error(Integer):
    tagSet: Any

class NmasGetUniversalPasswordRequestValue(Sequence):
    componentType: Any

class NmasGetUniversalPasswordResponseValue(Sequence):
    componentType: Any

class NmasSetUniversalPasswordRequestValue(Sequence):
    componentType: Any

class NmasSetUniversalPasswordResponseValue(Sequence):
    componentType: Any

class ReplicaList(SequenceOf):
    componentType: Any

class ReplicaInfoRequestValue(Sequence):
    tagSet: Any
    componentType: Any

class ReplicaInfoResponseValue(Sequence):
    tagSet: Any
    componentType: Any

class CreateGroupTypeRequestValue(Sequence):
    componentType: Any

class CreateGroupTypeResponseValue(Sequence):
    componentType: Any

class EndGroupTypeRequestValue(Sequence):
    componentType: Any

class EndGroupTypeResponseValue(Sequence):
    componentType: Any

class GroupingControlValue(Sequence):
    componentType: Any
